@@ -640,9 +640,12 @@ Readonly::Hash our %LANGUAGES => (
 	'yat' => 'Yambeta', # Yambeta - T263946
 	'yav' => 'Yangben', # Yangben - T263946
 	'ybb' => 'Yemba', # Yemba - T263946
+
+	# Other, used in Q111803082
+	'ak' => 'Akan',
 );
 
-our $VERSION = 0.36;
+our $VERSION = 0.37;
 
 sub all_language_codes {
 	return keys %LANGUAGES;
@@ -711,6 +714,7 @@ Returns array with codes.
  # aeb-latn
  # af
  # agq
+ # ak
  # aln
  # als
  # alt
@@ -1336,6 +1340,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.36
+0.37
 
 =cut
